

models.representations.BaseRepresentation
=========================================

.. note:: This module contains the implemented representation classes for all property representations that may be added to KE-chain.

.. autoclass:: pykechain.models.representations.representation_base.BaseRepresentation
   :members:

.. autoclass:: pykechain.models.representations.component.RepresentationsComponent
   :members:

.. autoclass:: pykechain.models.representations.representations.DecimalPlaces
   :members:

.. autoclass:: pykechain.models.representations.representations.SignificantDigits
   :members:


.. autoclass:: pykechain.models.representations.representations.LinkTarget
   :members:


.. autoclass:: pykechain.models.representations.representations.ButtonRepresentation
   :members:


.. autoclass:: pykechain.models.representations.representations.Autofill
   :members:


.. autoclass:: pykechain.models.representations.representations.CustomIconRepresentation
   :members:


.. autoclass:: pykechain.models.representations.representations.GeoCoordinateRepresentation
   :members:


.. autoclass:: pykechain.models.representations.representations.UsePropertyNameRepresentation
   :members:


.. autoclass:: pykechain.models.representations.representations.CameraScannerInputRepresentation
   :members:
